#[non_exhaustive]pub enum NodeJsArch {
X64,
X86,
Arm64,
Armv6l,
Armv7l,
Ppc64,
Ppc64le,
S390x,
}Expand description
The CPU architecture a Node.js distributable targets
Non-exhaustive: Node.js has added and removed target architectures over time, so new variants may appear in a minor release
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
X64
64-bit x86 (x64)
X86
32-bit x86 (x86)
Arm64
64-bit ARM (arm64)
Armv6l
32-bit ARMv6 with hardware floating point (armv6l) - shipped up to
Node.js v11
Armv7l
32-bit ARMv7 with hardware floating point (armv7l) - shipped up to
Node.js v23
Ppc64
64-bit PowerPC, big-endian (ppc64)
Ppc64le
64-bit PowerPC, little-endian (ppc64le)
S390x
64-bit IBM Z (s390x)
Implementations
Sourceimpl NodeJsArch
impl NodeJsArch
Sourcepub fn new() -> NodeJsArch
pub fn new() -> NodeJsArch
Sourcepub fn from_env() -> Result<NodeJsArch, NodeJsRelInfoError>
pub fn from_env() -> Result<NodeJsArch, NodeJsRelInfoError>
Determines the architecture of the current environment via
std::env::consts::ARCH
Errors
Returns NodeJsRelInfoError::UnrecognizedArch when the current
architecture has no corresponding Node.js distributable