#[non_exhaustive]pub enum NodeJsOs {
Linux,
Darwin,
Windows,
Aix,
SunOs,
}Expand description
The operating system a Node.js distributable targets
Non-exhaustive: Node.js has added and removed target platforms over time, so new variants may appear in a minor release
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Linux
Linux (linux)
Darwin
macOS (darwin)
Windows
Windows (win)
Aix
IBM AIX (aix)
SunOs
illumos / Solaris (sunos) - shipped up to Node.js v14
Implementations
Sourceimpl NodeJsOs
impl NodeJsOs
Sourcepub fn from_env() -> Result<NodeJsOs, NodeJsRelInfoError>
pub fn from_env() -> Result<NodeJsOs, NodeJsRelInfoError>
Determines the OS of the current environment via
std::env::consts::OS
Errors
Returns NodeJsRelInfoError::UnrecognizedOs when the current OS has
no corresponding Node.js distributable