#[non_exhaustive]pub enum NodeJsPkgExt {
Targz,
Tarxz,
Zip,
Msi,
S7z,
}Expand description
The file extension of a Node.js distributable
Non-exhaustive: Node.js has added and removed package formats over time, so new variants may appear in a minor release
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Targz
gzip-compressed tarball (tar.gz)
Tarxz
xz-compressed tarball (tar.xz)
Zip
zip archive (zip) - Windows only
Msi
Windows installer package (msi)
S7z
7-Zip archive (7z) - Windows only
Implementations
Sourceimpl NodeJsPkgExt
impl NodeJsPkgExt
Sourcepub fn new() -> NodeJsPkgExt
pub fn new() -> NodeJsPkgExt